==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListStaticSiteBuildFunctionAppSettingsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName The stage site identifier.
 * @property name Name of the static site.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class ListStaticSiteBuildFunctionAppSettingsPlainArgs(
    public val environmentName: String,
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs =
        com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListStaticSiteBuildFunctionAppSettingsPlainArgs].
 */
@PulumiTagMarker
public class ListStaticSiteBuildFunctionAppSettingsPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The stage site identifier.
     */
    @JvmName("hnhbqgjxerreubmy")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value Name of the static site.
     */
    @JvmName("qbcnwqiagbvbsjjd")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("qqjsjxmvnsclxofn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListStaticSiteBuildFunctionAppSettingsPlainArgs =
        ListStaticSiteBuildFunctionAppSettingsPlainArgs(
            environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListStaticSiteBuildFunctionAppSettingsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property environmentName The stage site identifier.
 * @property name Name of the static site.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class ListStaticSiteBuildFunctionAppSettingsPlainArgs(
    public val environmentName: String,
    public val name: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs =
        com.pulumi.azurenative.web.inputs.ListStaticSiteBuildFunctionAppSettingsPlainArgs.builder()
            .environmentName(environmentName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListStaticSiteBuildFunctionAppSettingsPlainArgs].
 */
@PulumiTagMarker
public class ListStaticSiteBuildFunctionAppSettingsPlainArgsBuilder internal constructor() {
    private var environmentName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The stage site identifier.
     */
    @JvmName("vbaqmepdhrukcooq")
    public suspend fun environmentName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.environmentName = mapped
    }

    /**
     * @param value Name of the static site.
     */
    @JvmName("ltljpjyvhsremnda")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("hompiuedgwkawxpm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListStaticSiteBuildFunctionAppSettingsPlainArgs =
        ListStaticSiteBuildFunctionAppSettingsPlainArgs(
            environmentName = environmentName ?: throw PulumiNullFieldException("environmentName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
